==> codebuild-1.60.0-sources.jar: software/amazon/awscdk/services/codebuild/BuildSpec.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * BuildSpec for CodeBuild projects.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:29.388Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.BuildSpec")
public abstract class BuildSpec extends software.amazon.jsii.JsiiObject {

    protected BuildSpec(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BuildSpec(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected BuildSpec() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.BuildSpec fromObject(final @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> value) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.BuildSpec.class, "fromObject", software.amazon.awscdk.services.codebuild.BuildSpec.class, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * Use a file from the source as buildspec.
     * <p>
     * Use this if you want to use a file different from 'buildspec.yml'`
     * <p>
     * @param filename This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.BuildSpec fromSourceFilename(final @org.jetbrains.annotations.NotNull java.lang.String filename) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.BuildSpec.class, "fromSourceFilename", software.amazon.awscdk.services.codebuild.BuildSpec.class, new Object[] { java.util.Objects.requireNonNull(filename, "filename is required") });
    }

    /**
     * Render the represented BuildSpec.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull java.lang.String toBuildSpec();

    /**
     * Whether the buildspec is directly available or deferred until build-time.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull java.lang.Boolean getIsImmediate();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.services.codebuild.BuildSpec {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Whether the buildspec is directly available or deferred until build-time.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public @org.jetbrains.annotations.NotNull java.lang.Boolean getIsImmediate() {
            return this.jsiiGet("isImmediate", java.lang.Boolean.class);
        }

        /**
         * Render the represented BuildSpec.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public @org.jetbrains.annotations.NotNull java.lang.String toBuildSpec() {
            return this.jsiiCall("toBuildSpec", java.lang.String.class);
        }
    }
}

==> codebuild-1.93.0-sources.jar: software/amazon/awscdk/services/codebuild/BuildSpec.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * BuildSpec for CodeBuild projects.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:46.547Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.BuildSpec")
public abstract class BuildSpec extends software.amazon.jsii.JsiiObject {

    protected BuildSpec(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BuildSpec(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected BuildSpec() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.BuildSpec fromObject(final @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, ? extends java.lang.Object> value) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.BuildSpec.class, "fromObject", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codebuild.BuildSpec.class), new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * Use a file from the source as buildspec.
     * <p>
     * Use this if you want to use a file different from 'buildspec.yml'`
     * <p>
     * @param filename This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.BuildSpec fromSourceFilename(final @org.jetbrains.annotations.NotNull java.lang.String filename) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.BuildSpec.class, "fromSourceFilename", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codebuild.BuildSpec.class), new Object[] { java.util.Objects.requireNonNull(filename, "filename is required") });
    }

    /**
     * Render the represented BuildSpec.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull java.lang.String toBuildSpec();

    /**
     * Whether the buildspec is directly available or deferred until build-time.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull java.lang.Boolean getIsImmediate();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.codebuild.BuildSpec {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Whether the buildspec is directly available or deferred until build-time.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.Boolean getIsImmediate() {
            return software.amazon.jsii.Kernel.get(this, "isImmediate", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Render the represented BuildSpec.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final @org.jetbrains.annotations.NotNull java.lang.String toBuildSpec() {
            return software.amazon.jsii.Kernel.call(this, "toBuildSpec", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }
    }
}
